# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import enum

import winrt.system
from winrt import _winrt_windows_devices_scanners

__all__ = [
    "ImageScannerAutoCroppingMode",
    "ImageScannerColorMode",
    "ImageScannerFormat",
    "ImageScannerScanSource",
    "ImageScannerResolution",
    "ImageScanner",
    "ImageScannerAutoConfiguration",
    "ImageScannerFeederConfiguration",
    "ImageScannerFlatbedConfiguration",
    "ImageScannerPreviewResult",
    "ImageScannerScanResult",
    "IImageScannerFormatConfiguration",
    "IImageScannerSourceConfiguration",
]

class ImageScannerAutoCroppingMode(enum.IntEnum):
    DISABLED = 0
    SINGLE_REGION = 1
    MULTIPLE_REGION = 2

class ImageScannerColorMode(enum.IntEnum):
    COLOR = 0
    GRAYSCALE = 1
    MONOCHROME = 2
    AUTO_COLOR = 3

class ImageScannerFormat(enum.IntEnum):
    JPEG = 0
    PNG = 1
    DEVICE_INDEPENDENT_BITMAP = 2
    TIFF = 3
    XPS = 4
    OPEN_XPS = 5
    PDF = 6

class ImageScannerScanSource(enum.IntEnum):
    DEFAULT = 0
    FLATBED = 1
    FEEDER = 2
    AUTO_CONFIGURED = 3

ImageScannerResolution = _winrt_windows_devices_scanners.ImageScannerResolution
ImageScanner = _winrt_windows_devices_scanners.ImageScanner
ImageScannerAutoConfiguration = _winrt_windows_devices_scanners.ImageScannerAutoConfiguration
ImageScannerFeederConfiguration = _winrt_windows_devices_scanners.ImageScannerFeederConfiguration
ImageScannerFlatbedConfiguration = _winrt_windows_devices_scanners.ImageScannerFlatbedConfiguration
ImageScannerPreviewResult = _winrt_windows_devices_scanners.ImageScannerPreviewResult
ImageScannerScanResult = _winrt_windows_devices_scanners.ImageScannerScanResult
IImageScannerFormatConfiguration = _winrt_windows_devices_scanners.IImageScannerFormatConfiguration
IImageScannerSourceConfiguration = _winrt_windows_devices_scanners.IImageScannerSourceConfiguration
